==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/SummaryRowRootDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryRowDescriptionMetadata } from "./SummaryRowDescriptionMetadata";
import { SummaryRowRootDescription } from "./SummaryRowRootDescription";
/**
 * @hidden
 */
export let SummaryRowRootDescriptionMetadata = /*@__PURE__*/ (() => {
    class SummaryRowRootDescriptionMetadata extends Base {
        static b(a) {
            if (SummaryRowRootDescriptionMetadata.a == null) {
                SummaryRowRootDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SummaryRowRootDescriptionMetadata.c(SummaryRowRootDescriptionMetadata.a);
            }
            if (a.k(SummaryRowRootDescriptionMetadata.a)) {
                return;
            }
            a.ab(SummaryRowRootDescriptionMetadata.a);
        }
        static c(a) {
            SummaryRowDescriptionMetadata.c(a);
        }
        static d(a) {
            SummaryRowRootDescriptionMetadata.b(a);
            a.ad("SummaryRowRoot", () => new SummaryRowRootDescription());
            a.ac("SummaryRowRoot", SummaryRowRootDescriptionMetadata.a);
        }
    }
    SummaryRowRootDescriptionMetadata.$t = markType(SummaryRowRootDescriptionMetadata, 'SummaryRowRootDescriptionMetadata');
    SummaryRowRootDescriptionMetadata.a = null;
    return SummaryRowRootDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/SummaryRowRootDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryRowDescriptionMetadata } from "./SummaryRowDescriptionMetadata";
import { SummaryRowRootDescription } from "./SummaryRowRootDescription";
/**
 * @hidden
 */
export let SummaryRowRootDescriptionMetadata = /*@__PURE__*/ (() => {
    class SummaryRowRootDescriptionMetadata extends Base {
        static b(a) {
            if (SummaryRowRootDescriptionMetadata.a == null) {
                SummaryRowRootDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SummaryRowRootDescriptionMetadata.c(SummaryRowRootDescriptionMetadata.a);
            }
            if (a.k(SummaryRowRootDescriptionMetadata.a)) {
                return;
            }
            a.ac(SummaryRowRootDescriptionMetadata.a);
        }
        static c(a) {
            SummaryRowDescriptionMetadata.c(a);
        }
        static d(a) {
            SummaryRowRootDescriptionMetadata.b(a);
            a.ae("SummaryRowRoot", () => new SummaryRowRootDescription());
            a.ad("SummaryRowRoot", SummaryRowRootDescriptionMetadata.a);
        }
    }
    SummaryRowRootDescriptionMetadata.$t = markType(SummaryRowRootDescriptionMetadata, 'SummaryRowRootDescriptionMetadata');
    SummaryRowRootDescriptionMetadata.a = null;
    return SummaryRowRootDescriptionMetadata;
})();
